@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * programs/gchemtable-elt.cc 
  *
- * Copyright (C) 2005-2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -29,17 +29,13 @@
 #include <glib/gi18n.h>
 #include <list>
 
-#warning "the following lines should be removed for stable releases"
-#undef PACKAGE
-#define PACKAGE "gchemutils-unstable" 
-
 extern void on_show_curve (GObject *obj, char const* name);
 static void on_focus_in (GChemTableElt *dlg)
 {
 	dlg->OnFocusIn ();
 }
 
-GChemTableElt::GChemTableElt (GChemTableApp *App, int Z): Dialog (App, DATADIR"/"PACKAGE"/glade/eltpage.glade", "eltdlg")
+GChemTableElt::GChemTableElt (GChemTableApp *App, int Z): Dialog (App, GLADEDIR"/eltpage.glade", "eltdlg")
 {
 	Element *elt = Element::GetElement (Z);
 	m_Z = Z;
@@ -124,13 +120,15 @@ GChemTableElt::GChemTableElt (GChemTableApp *App, int Z): Dialog (App, DATADIR"/
 			gtk_table_resize (table, 4, n);
 			buf = g_strdup_printf (_("%d:"), n);
 			w = gtk_label_new (buf);
-			g_free (buf);
+			gtk_misc_set_padding (GTK_MISC (w), 8, 0);
+ 			g_free (buf);
 			gtk_table_attach (table, w, 0, 1, n - 1, n,
 				(GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
 				(GtkAttachOptions) 0 , 0, 0);
 			val = gtk_label_new ("");
+			gtk_misc_set_alignment (GTK_MISC (val), 0., 0.);
 			gtk_table_attach (table, val, 1, 2, n - 1, n,
-				(GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
+				(GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 				(GtkAttachOptions) 0 , 0, 0);
 			button = gtk_button_new_with_label (_("Show curve"));
 			gtk_table_attach (table, button, 2, 3, n - 1, n,
@@ -146,7 +144,6 @@ GChemTableElt::GChemTableElt (GChemTableApp *App, int Z): Dialog (App, DATADIR"/
 		buf = g_strdup_printf ("ei/%d", n);
 		g_object_set_data (G_OBJECT (button), "app", App);
 		g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_show_curve), (void*) buf);
-#warning FIXME: clean this on exit
 		n++;
 	}
 	gtk_widget_show_all (GTK_WIDGET (table));
@@ -164,13 +161,14 @@ GChemTableElt::GChemTableElt (GChemTableApp *App, int Z): Dialog (App, DATADIR"/
 			gtk_table_resize (table, 4, n);
 			buf = g_strdup_printf (_("%d:"), n);
 			w = gtk_label_new (buf);
+			gtk_misc_set_alignment (GTK_MISC (w), 0., 0.);
 			g_free (buf);
 			gtk_table_attach (table, w, 0, 1, n - 1, n,
 				(GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
 				(GtkAttachOptions) 0 , 0, 0);
 			val = gtk_label_new ("");
 			gtk_table_attach (table, val, 1, 2, n - 1, n,
-				(GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
+				(GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 				(GtkAttachOptions) 0 , 0, 0);
 			button = NULL; // not enough values to draw a curve.
 		} else {
@@ -316,7 +314,7 @@ GChemTableElt::GChemTableElt (GChemTableApp *App, int Z): Dialog (App, DATADIR"/
 				spin = _("High");
 				break;
 			default:
-				spin = "";
+				spin = (char*) "";
 				break;
 			}
 			buf = gcu_dimensional_value_get_string (&(*j)->value);
@@ -332,7 +330,6 @@ GChemTableElt::GChemTableElt (GChemTableApp *App, int Z): Dialog (App, DATADIR"/
 			g_free (buf);
 		}
 	}
-#ifdef WITH_BODR
 	Value *prop = elt->GetProperty ("meltingpoint");
 	button = glade_xml_get_widget (xml, "melting-btn");
 	if (prop) {
@@ -351,10 +348,6 @@ GChemTableElt::GChemTableElt (GChemTableApp *App, int Z): Dialog (App, DATADIR"/
 		g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_show_curve), (void*) "bp");
 	} else
 		gtk_widget_hide (button);
-#else
-	w = glade_xml_get_widget (xml, "thermal-table");
-	gtk_widget_hide (w);
-#endif
 }
 
 GChemTableElt::~GChemTableElt ()
